diff --git a/core/modules/system/tests/modules/form_test/src/Form/FormTestDisabledElementsForm.php b/core/modules/system/tests/modules/form_test/src/Form/FormTestDisabledElementsForm.php
index 56e6d2ee0f..97b4dc0e3d 100644
--- a/core/modules/system/tests/modules/form_test/src/Form/FormTestDisabledElementsForm.php
+++ b/core/modules/system/tests/modules/form_test/src/Form/FormTestDisabledElementsForm.php
@@ -34,7 +34,7 @@ public function buildForm(array $form, FormStateInterface $form_state) {
       ];
     }
 
     // Multiple values option elements.
     foreach (['checkboxes', 'select'] as $type) {
       $form[$type . '_multiple'] = [
         '#type' => $type,
@@ -52,6 +52,36 @@ public function buildForm(array $form, FormStateInterface $form_state) {
       ];
     }
 
+    // Multiple values option elements, only single options disabled.
+    foreach (['checkboxes', 'select'] as $type) {
+      $form[$type . '_single_select'] = [
+        '#type' => $type,
+        '#title' => $type . ' (multiple)',
+        '#options' => [
+          'test_1' => 'Test 1',
+          'test_2' => 'Test 2',
+        ],
+        '#multiple' => TRUE,
+        '#default_value' => ['test_2' => 'test_2'],
+        'test_1' => [
+          '#disabled' => TRUE,
+        ],
+      ];
+      $form[$type . '_single_unselect'] = [
+        '#type' => $type,
+        '#title' => $type . ' (multiple)',
+        '#options' => [
+          'test_1' => 'Test 1',
+          'test_2' => 'Test 2',
+        ],
+        '#multiple' => TRUE,
+        '#default_value' => ['test_2' => 'test_2'],
+        'test_2' => [
+          '#disabled' => TRUE,
+        ],
+      ];
+    }
+
     // Single values option elements.
     foreach (['radios', 'select'] as $type) {
       $form[$type . '_single'] = [
@@ -34,7 +34,7 @@ public function buildForm(array $form, FormStateInterface $form_state) {
     }
 
-    // Multiple values option elements.
+    // Multiple values option elements, disabled as a whole.
     foreach (['checkboxes', 'select'] as $type) {
       $form[$type . '_multiple'] = [
